@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -25,9 +25,9 @@
          University of Manchester, Manchester, M13 9PL, UK
 */
 
+#include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <sys/time.h>
 #include <math.h>
 #include "maverik.h"
 #include "mav_escapeavatar.h"
@@ -38,7 +38,7 @@ extern ThreeDObjParams *deva_getTDP(MAV_object *);
 MAV_class *mav_class_avatar;
 #endif
 
-struct timeval Astarttime,Aendtime;
+MAV_timer Atimer;
 extern int wire;
 
 char files[NUM_PARTS][100] = {
@@ -142,12 +142,8 @@ MAV_vector relative_positions[NUM_PARTS] = {
 double
 mav_getTimer (void)
 {
-  int elapsedSec, elapsedUSec;
-
-  gettimeofday(&Aendtime, NULL);
-  elapsedSec= Aendtime.tv_sec-Astarttime.tv_sec;
-  elapsedUSec= Aendtime.tv_usec-Astarttime.tv_usec;
-  return (elapsedSec+elapsedUSec/1.0E+6);
+  mav_timerStop(&Atimer);
+  return Atimer.wall;
 }
 
 int
@@ -412,7 +408,7 @@ mav_avatarInitialise (void)
   mav_paletteColourSet (mav_palette_default, COLOUR_SKIN, 0.800,0.544,0.455,0.0);
   mav_paletteColourSet (mav_palette_default, COLOUR_HAIR, 0.267,0.145,0.020,0.0);
   mav_paletteColourSet (mav_palette_default, COLOUR_BLUE, 0.043,0.282,0.529,0.0);
-  gettimeofday(&Astarttime, NULL);
+  mav_timerStart(&Atimer);
 }
 
 MAV_avatar*
