@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -311,20 +311,24 @@ Feature *feature;
 int feature_vertices;
 int num_polygons;
 
-void my_begin(GLenum mode)
+#ifndef CALLBACK
+#define CALLBACK
+#endif
+
+void CALLBACK my_begin(GLenum mode)
 {
   feature->polys[feature->num_polys].num_verts= 3;
   feature->polys[feature->num_polys].verts= mav_malloc(3*sizeof(MAV_vector));
   feature->polys[feature->num_polys].num_verts= 0;
 }
 
-void my_error(GLenum en)
+void CALLBACK my_error(GLenum en)
 {
   printf("GLU error: %s\n", gluErrorString(en));
   exit(0);
 }
 
-void my_vertex(void *v)
+void CALLBACK my_vertex(void *v)
 {
   MAV_vector r0,r1;
 
@@ -340,7 +344,7 @@ void my_vertex(void *v)
   }
 }
 
-void count_polygons(void *v)
+void CALLBACK count_polygons(void *v)
 {
   feature_vertices++;
 
@@ -350,7 +354,7 @@ void count_polygons(void *v)
   }
 }
 
-void my_edge_flag()
+void CALLBACK my_edge_flag(GLboolean flag)
 {
 }
 
