@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -758,20 +758,24 @@ void Make_Font(void)
 Feature *feature;
 int feature_vertices;
 
-void my_begin(GLenum mode)
+#ifndef CALLBACK
+#define CALLBACK
+#endif
+
+void CALLBACK my_begin(GLenum mode)
 {
   feature->polys[feature->num_polys].num_verts= 3;
   feature->polys[feature->num_polys].verts= mav_malloc(3*sizeof(MAV_vector));
   feature->polys[feature->num_polys].num_verts= 0;
 }
 
-void my_error(GLenum en)
+void CALLBACK my_error(GLenum en)
 {
   printf("GLU error: %i\n",en);
   exit(0);
 }
 
-void my_vertex(void *v)
+void CALLBACK my_vertex(void *v)
 {
   MAV_vector r0,r1;
 
@@ -787,11 +791,11 @@ void my_vertex(void *v)
   }
 }
 
-GLvoid dummyedge(void)
+void CALLBACK dummyedge(GLboolean flag)
 {
 }
 
-GLvoid count_polygons(void)
+void CALLBACK count_polygons(void *ignored)
 {
   feature_vertices++;
 
@@ -801,11 +805,11 @@ GLvoid count_polygons(void)
   }
 }
 
-void dummybegin(GLenum mode)
+void CALLBACK dummybegin(GLenum mode)
 {
 }
 
-void dummyend()
+void CALLBACK dummyend(void)
 {
 }
 
@@ -2417,7 +2421,7 @@ float timediff;
 
 
  
-void LCjoyMove(void)
+void LCjoyMove(void *ignored)
 {
 #if 0
  float xdiff,ydiff;
@@ -2650,7 +2654,7 @@ void mav_LCityModuleInit(void)
   mav_FFJoyForceClear();
 
   mav_callbackFFJoySet(mav_win_all,mav_class_world,LCjoyPress);
-  mav_frameFn1Add(LCjoyMove);
+  mav_frameFn1Add(LCjoyMove, NULL);
 */
           
   /* construct HBB from objList */
@@ -2710,7 +2714,7 @@ int main(int argc, char *argv[])
   mav_opt_maxMaterials=750;
   mav_opt_maxColours=750;
   if (argc>1) mav_opt_stereo= MAV_STEREO_TWO_WINS;
-  mav_initialiseArgs(&argc, argv);
+  mav_initialise(&argc, argv);
   mav_LCityModuleInit();
 
   /* Set background color */ 
